@@ -80,7 +80,7 @@ class DataMediator:
     def transposeDataFrame(
         dataframe,
         columnToTranspose: str,
-        columnsToDrop: Union[List[str], slice] = None,
+        columnsToDrop: Union[List[str], slice] = [],
     ) -> DataFrame:
         """
         Static method to transpose a dataframe by a given column,
@@ -295,7 +295,7 @@ class DataMediator:
                 random_state=self.randomSeed,
             )
 
-    def loadPredictions(self, probabilities: list, dataGroup: str = "test"):
+    def loadPredictions(self, probabilities: list, dataGroup: str):
         """
         Index an array-like of numeric predictions into a dataframe. Training & testing
         data must be split before using this method.
@@ -314,6 +314,6 @@ class DataMediator:
                 if dataGroup == "train"
                 else self.holdoutLabels,
                 "y_pred": np.argmax(probabilities, axis=1),
-                "y_probas": list(probabilities),
+                "y_probas": [probabilities],
             }
         )
